<?php

namespace Iwaydev\AirlinesClient;

use \DomainException;
use Iwaydev\BaseSender\Sender;
use JsonException;
use Psr\Http\Message\ResponseInterface;

/**
 * Class AirlinesClient
 *
 * @package Iwaydev\AirlinesClient
 */
class AirlinesClient extends Sender
{
    /**
     * Авторизация
     *
     * @param string $token Токен авторизации
     *
     * @return $this
     */
    public function auth(string $token): self
    {
        $this->setHeader('Authorization', 'Basic ' . $token);

        return $this;
    }

    /**
     * Возвращает информацию о рейсе
     *
     * @param array $query Фильтры
     *
     * @return array
     * @throws JsonException
     */
    public function getFlight(array $query = []): array
    {
        return $this->post('flights/find', $query);
    }

    /**
     * Получение статистики по основным компонентам проекта
     *
     * @param array $data
     *
     * @return array
     * @throws JsonException
     */
    public function monitor(array $data = []): array
    {
        return $this->get('monitor', $data);
    }

    /**
     * @inheritDoc
     */
    protected function prepareResponse(ResponseInterface $response): array
    {
        $responseData = parent::prepareResponse($response);

        if (isset($responseData['result'])) {
            return $responseData['result'];
        }

        $message = reset($responseData['error']);
        $message = is_array($message) ? $message : $responseData['error'];
        $message = $message['message'] ?? implode(' ', $message);

        throw new DomainException($message);
    }
}
