<?php

namespace Iwaydev\AirlinesClient;

use Illuminate\Support\ServiceProvider;

/**
 * Провайдер Airlines
 *
 * @package Iwaydev\AirlinesClient
 */
class AirlinesServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     *
     * @return void
     */
    public function register(): void
    {
        parent::register();

        $this->setDefaultLogChannel();

        $this->registerSender();
    }

    /**
     * Добавляет в конфиг канал для логирования, если отсутствует
     */
    protected function setDefaultLogChannel(): void
    {
        if (!config()->has('logging.channels.airlines')) {
            config()->set('logging.channels.airlines', require __DIR__ . '/../config/log-airlines.php');
        }
    }

    /**
     * Регистрирует сендер для общения с сервисов авторизации
     */
    protected function registerSender(): void
    {
        $this->app->singleton(AirlinesClient::class, function ($app) {
            return new AirlinesClient(
                config('senders.airlines.connection.url'),
                config('senders.airlines.connection.api_version'),
                cache()->store(),
                config('senders.airlines.cache.lifetime'),
                logs('airlines'),
                $app->request->header('X-UUID', null)
            );
        });
    }

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot(): void
    {
        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../config/airlines.php' => config_path('senders/airlines.php'),
            ], 'config');

            $this->publishes([
                __DIR__ . '/AirlinesServiceProvider.php' => app_path('Providers/AirlinesServiceProvider.php'),
            ], 'provider');
        }
    }
}
